YCM 0.13.1 (2022-03-31) Release Notes
*************************************

.. only:: html

  .. contents::

Changes made since YCM 0.13.0 include the following.

Important Changes
=================

* The ``ExternalProject`` module vendored in YCM (used in ``YCMBootstrap``)
  has been updated for compatibility with CMake 3.23 .

* FindGraphviz: Fix finding graphviz not installed in system directories .
